@@ -1,19 +1,19 @@
-
 /*****************************************************************************
-**  This is part of the g2 library
-**  Copyright (C) 1998  Ljubomir Milanovic & Horst Wagner
+**  Copyright (C) 1998-2001  Ljubomir Milanovic & Horst Wagner
+**  This file is part of the g2 library
 **
-**  This program is free software; you can redistribute it and/or modify
-**  it under the terms of the GNU General Public License (version 2) as
-**  published by the Free Software Foundation.
+**  This library is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU Lesser General Public
+**  License as published by the Free Software Foundation; either
+**  version 2.1 of the License, or (at your option) any later version.
 **
-**  This program is distributed in the hope that it will be useful,
+**  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
-**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-**  GNU General Public License for more details.
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
+**  You should have received a copy of the GNU Lesser General Public
+**  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
 
@@ -26,8 +26,8 @@
 #ifdef DO_X11
 #include <g2_X11.h>
 #endif
-#ifdef DO_GIF
-#include <g2_GIF.h>
+#ifdef DO_GD
+#include <g2_gd.h>
 #endif
 #ifdef DO_WIN32
 #include <g2_win32.h>
@@ -36,12 +36,13 @@
 #include <g2_win32.h>
 #endif
 
-#define ndev 5
+#define maxdev 10
 
 int main()
 {
     int i, j;
-    int d, dev[ndev]={-1, -1, -1, -1, -1};
+    int d, dev[maxdev]={-1, -1, -1, -1, -1,-1, -1, -1, -1, -1};
+	int ndev=0;
     char str[256];
     double pts[10];
     double y;
@@ -60,32 +61,50 @@ int main()
     
 #ifdef DO_PS
     printf("..PS");
-    dev[0]=g2_open_PS("g2_test.ps", g2_A4, g2_PS_land);
-    g2_attach(d, dev[0]);
+    dev[ndev]=g2_open_PS("g2_test.ps", g2_A4, g2_PS_land);
+    g2_attach(d, dev[ndev]);
+	ndev++;
+	
+    printf("..EPSF");
+    dev[ndev]=g2_open_EPSF("g2_test.eps");
+    g2_attach(d, dev[ndev]);
+	ndev++;
+    printf("..EPSF_CLIP");
+    dev[ndev]=g2_open_EPSF_CLIP("g2_test_clip.eps",200,200);
+    g2_attach(d, dev[ndev]);
+	ndev++;
 #endif
 #ifdef DO_X11
     printf("..X11");
-    dev[1]=g2_open_X11(775, 575);
-    g2_attach(d, dev[1]);
+    dev[ndev]=g2_open_X11(775, 575);
+    g2_attach(d, dev[ndev]);
+	ndev++;
 #endif
-#ifdef DO_GIF
-    printf("..GIF");
-    dev[2]=g2_open_GIF("g2_test.gif", 775, 575);
-    g2_attach(d, dev[2]);
+#ifdef DO_GD
+    printf("..GD(png)");
+    dev[ndev]=g2_open_gd("g2_test.png", 775, 575,g2_gd_png);
+    g2_attach(d, dev[ndev]);
+	ndev++;
+    printf("..GD(jpeg)");
+    dev[ndev]=g2_open_gd("g2_test.jpg", 775, 575,g2_gd_jpeg);
+    g2_attach(d, dev[ndev]);
+	ndev++;
 #endif
 #ifdef DO_WIN32
     printf("..WIN32");
-    dev[3]=g2_open_win32(775, 575,"g2_test",0);
-	g2_set_auto_flush(dev[3],0);
-    g2_attach(d, dev[3]);
+    dev[ndev]=g2_open_win32(775, 575,"g2_test",0);
+	g2_set_auto_flush(dev[ndev],0);
+    g2_attach(d, dev[ndev]);
+	ndev++;
 #endif
 #ifdef DO_WMF32
     printf("..WMF32");
-    dev[4]=g2_open_win32(775, 575,"g2_test.emf",1);
-	g2_set_auto_flush(dev[3],0);
-    g2_attach(d, dev[4]);
+    dev[ndev]=g2_open_win32(775, 575,"g2_test.emf",1);
+	g2_set_auto_flush(dev[ndev],0);
+    g2_attach(d, dev[ndev]);
+	ndev++;
 #endif
-	g2_set_auto_flush(d,0);
+    g2_set_auto_flush(d,0);
 
     printf("\n");
 
@@ -120,7 +139,7 @@ int main()
     g2_line(d, 198, 46, 198, 75);
     g2_line(d, 196, 46, 196, 75);
     g2_string(d, 200, 50, "012abcABC#())(\\-+~*!$%&");
-    
+
     g2_pen(d, 1);
     for(i=1;i<25;i++) {
 	g2_line(d, 15, i*20+50, 15, i*20+50+i);
@@ -157,6 +176,9 @@ int main()
     pts[6]=225; pts[7]=y+100;
     pts[8]=250; pts[9]=y;
     g2_poly_line(d, 5, pts);
+    g2_pen(d, 19);
+    g2_b_spline(d, 5, pts, 20);
+    g2_pen(d, 1);
     
     pts[0]=300; pts[1]=y;
     pts[2]=350; pts[3]=y;
