@@ -1,18 +1,19 @@
 /*****************************************************************************
-**  This is part of the g2 library
-**  Copyright (C) 1998  Ljubomir Milanovic & Horst Wagner
+**  Copyright (C) 1998-2001  Ljubomir Milanovic & Horst Wagner
+**  This file is part of the g2 library
 **
-**  This program is free software; you can redistribute it and/or modify
-**  it under the terms of the GNU General Public License (version 2) as
-**  published by the Free Software Foundation.
+**  This library is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU Lesser General Public
+**  License as published by the Free Software Foundation; either
+**  version 2.1 of the License, or (at your option) any later version.
 **
-**  This program is distributed in the hope that it will be useful,
+**  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
-**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-**  GNU General Public License for more details.
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
+**  You should have received a copy of the GNU Lesser General Public
+**  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
 
@@ -181,19 +182,19 @@ int g2_GIF_Line(int pid, void *pdp, int x1, int y1, int x2, int y2)
 	  {
 	  float dx,dy,l;
 	  gdPoint points[4];
-	  dx=-(y2-y1);
-	  dy=x2-x1;
-	  l = PDP->LineWidth/sqrt(dy*dy+dx*dx)/2.;
-	  dx = dx*l;
-	  dy = dy*l;
-	  points[0].x = x1+dx;
-          points[0].y = y1+dy;
-          points[1].x = x1-dx;
-          points[1].y = y1-dy;
-          points[2].x = x2-dx;
-          points[2].y = y2-dy;
-          points[3].x = x2+dx;
-          points[3].y = y2+dy;
+	  dx = -(float)(y2-y1);
+	  dy =  (float)(x2-x1);
+	  l  =  (float)(PDP->LineWidth/sqrt(dy*dy+dx*dx)/2.);
+	  dx =  dx*l;
+	  dy =  dy*l;
+	  points[0].x = (int)(x1+dx);
+      points[0].y = (int)(y1+dy);
+      points[1].x = (int)(x1-dx);
+      points[1].y = (int)(y1-dy);
+      points[2].x = (int)(x2-dx);
+      points[2].y = (int)(y2-dy);
+      points[3].x = (int)(x2+dx);
+      points[3].y = (int)(y2+dy);
 	  gdImageFilledPolygon(PDP->im,points,4,PDP->CurCol);
 	  }
 	return 0;
