@@ -1,18 +1,19 @@
 /*****************************************************************************
-**  This is part of the g2 library
-**  Copyright (C) 1998  Ljubomir Milanovic & Horst Wagner
+**  Copyright (C) 1998-2001  Ljubomir Milanovic & Horst Wagner
+**  This file is part of the g2 library
 **
-**  This program is free software; you can redistribute it and/or modify
-**  it under the terms of the GNU General Public License (version 2) as
-**  published by the Free Software Foundation.
+**  This library is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU Lesser General Public
+**  License as published by the Free Software Foundation; either
+**  version 2.1 of the License, or (at your option) any later version.
 **
-**  This program is distributed in the hope that it will be useful,
+**  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
-**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-**  GNU General Public License for more details.
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
+**  You should have received a copy of the GNU Lesser General Public
+**  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
 #include <stdio.h>
@@ -654,9 +655,8 @@ int g2_X11_draw_string(int pid, void *pdp, int x, int y, char *text)
 }
 
 
-
-
-int g2_X11_image(int pid, int x, int y, int width, int height, int *pen_array)
+int g2_X11_image(int pid, void *pdp,
+		 int x, int y, int width, int height, int *pen_array)
 {
     g2_X11_device *xout=&g2_X11_dev[pid];
     XImage *image=NULL;
@@ -692,3 +692,25 @@ int g2_X11_image(int pid, int x, int y, int width, int height, int *pen_array)
     free(ink_array);
     return 0;
 }
+
+
+int g2_X11_query_pointer(int pid, void *pdp,
+			 int *x, int *y, unsigned int *button)
+{
+    Bool rv;
+    g2_X11_device *xout=&g2_X11_dev[pid];
+    Window root, child;
+    int rx, ry;
+
+    rv = XQueryPointer(xout->display, xout->window,
+		       &root, &child, &rx, &ry,
+		       x, y, button);
+
+    if(rv)
+	return 0;
+    else
+	return 1;
+}
+
+
+
