@@ -1,18 +1,19 @@
 /*****************************************************************************
-**  This is part of the g2 library
-**  Copyright (C) 1998  Ljubomir Milanovic & Horst Wagner
+**  Copyright (C) 1998-2001  Ljubomir Milanovic & Horst Wagner
+**  This file is part of the g2 library
 **
-**  This program is free software; you can redistribute it and/or modify
-**  it under the terms of the GNU General Public License (version 2) as
-**  published by the Free Software Foundation.
+**  This library is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU Lesser General Public
+**  License as published by the Free Software Foundation; either
+**  version 2.1 of the License, or (at your option) any later version.
 **
-**  This program is distributed in the hope that it will be useful,
+**  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
-**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-**  GNU General Public License for more details.
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
+**  You should have received a copy of the GNU Lesser General Public
+**  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
 #ifndef _G2_X11_P_H
@@ -74,7 +75,10 @@ int g2_X11_filled_arc(int pid, void *pdp, int x, int y,
 int g2_X11_ellipse(int pid, void *pdp, int x, int y, int r1, int r2);
 int g2_X11_filled_ellipse(int pid, void *pdp, int x, int y, int r1, int r2);
 int g2_X11_draw_string(int pid, void *pdp, int x, int y, char *text);
-int g2_X11_image(int pid, int x, int y, int width, int height, int *pen_array);
+int g2_X11_image(int pid, void *pdp,
+		 int x, int y, int width, int height, int *pen_array);
+int g2_X11_query_pointer(int pid, void *pdp,
+			 int *x, int *y, unsigned int *button);
 
 #endif /* _G2_X11_P_H */
 
