@@ -1,18 +1,19 @@
 /*****************************************************************************
-**  This is part of the g2 library
-**  Copyright (C) 1998  Ljubomir Milanovic & Horst Wagner
+**  Copyright (C) 1998-2001  Ljubomir Milanovic & Horst Wagner
+**  This file is part of the g2 library
 **
-**  This program is free software; you can redistribute it and/or modify
-**  it under the terms of the GNU General Public License (version 2) as
-**  published by the Free Software Foundation.
+**  This library is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU Lesser General Public
+**  License as published by the Free Software Foundation; either
+**  version 2.1 of the License, or (at your option) any later version.
 **
-**  This program is distributed in the hope that it will be useful,
+**  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
-**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-**  GNU General Public License for more details.
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
+**  You should have received a copy of the GNU Lesser General Public
+**  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
 #include <stdio.h>
@@ -129,7 +130,7 @@ void FIF(g2_close)(F_REAL *dev)
 
 void FIF(g2_set_auto_flush)(F_REAL *dev, F_REAL *on_off)
 {
-    g2_set_auto_flush(dtoi(*dev), *on_off);
+    g2_set_auto_flush(dtoi(*dev), dtoi(*on_off));
 }
 
 
@@ -334,7 +335,7 @@ void FIF(g2_reset_palette)(F_REAL *dev)
 
 void FIF(g2_set_background)(F_REAL *dev, F_REAL *color)
 {
-    g2_set_background(dtoi(*dev), *color);
+    g2_set_background(dtoi(*dev), dtoi(*color));
 }
 
 
@@ -365,7 +366,7 @@ void FIF(g2_triangle)(F_REAL *dev, F_REAL *x1, F_REAL *y1,
 
 void FIF(g2_set_qp)(F_REAL *dev, F_REAL *d, F_REAL *shape)
 {
-    g2_set_QP(dtoi(*dev), *d, *shape);
+    g2_set_QP(dtoi(*dev), *d, dtoi(*shape));
 }
 
 
