@@ -1,18 +1,19 @@
 /*****************************************************************************
-**  This is part of the g2 library
-**  Copyright (C) 1998  Ljubomir Milanovic & Horst Wagner
+**  Copyright (C) 1998-2001  Ljubomir Milanovic & Horst Wagner
+**  This file is part of the g2 library
 **
-**  This program is free software; you can redistribute it and/or modify
-**  it under the terms of the GNU General Public License (version 2) as
-**  published by the Free Software Foundation.
+**  This library is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU Lesser General Public
+**  License as published by the Free Software Foundation; either
+**  version 2.1 of the License, or (at your option) any later version.
 **
-**  This program is distributed in the hope that it will be useful,
+**  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
-**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-**  GNU General Public License for more details.
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
+**  You should have received a copy of the GNU Lesser General Public
+**  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
 #include <stdio.h>
@@ -457,3 +458,33 @@ void g2_set_QP(int dev, double d, enum QPshape shape)
     __g2_last_device=dev;
 }
 
+
+/*
+ *
+ * Query pointer position and button state
+ *
+ */
+void g2_query_pointer(int dev, double *x, double *y, unsigned int *button)
+{
+    g2_device *devp;
+    int i;
+    
+    if((devp=g2_get_device_pointer(dev))==NULL) {
+	fprintf(stderr, "g2_query_pointer: No such device: %d\n", dev);
+	return;
+    }
+    
+    switch(devp->t) {
+      case g2_PD:
+	g2_query_pointer_pd(devp->d.pd, x, y, button);
+	break;
+      case g2_VD:
+	break;
+      case g2_ILLEGAL:
+	break;
+      case g2_NDEV:
+	break;
+    }   
+    __g2_last_device=dev;
+}
+
